FlumeTypographyData class Foundation
Baseline typography data.
Constructors
- FlumeTypographyData({required double fontSize, required FontWeight fontWeight, required double lineHeight, required String fontFamily, String? package})
-
const
Properties
- fontFamily → String Foundation
-
Font family.
final
- fontSize → double Foundation
-
Font size.
final
- fontWeight → FontWeight Foundation
-
Font weight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineHeight → double Foundation
-
Line height.
final
- package → String? Foundation
-
The package from which the font family is loaded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTextStyle(
) → TextStyle Foundation - Returns a TextStyle instance created from the current FlumeTypographyData.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited